==> V04.036.zip: tweet_live-V04.036/web/enmi15/session-3/config.php <==
<?php
$config = array(
   	'hashtag'    => '#enmi15',
    'annotation_protocol_version' => '2',

   	'title' => "Entretiens du Nouveau Monde Industriel 2015, Session 3",

	'abstract'   => "<b>LA TOILE QUE NOUS VOULONS</b><br>Du web sémantique au web herméneutique<br>
    <p>Paris. Centre Pompidou. Grande Salle.<br>
    14 et 15 décembre 2015<br>
    <a href=\"http://enmi-conf.org\" target=\"_blank\">http://enmi-conf.org</a>
    </p>",

   	'description'=> "<h3>Espace public, études digitales et éditorialisation</h3>
    <p><strong>Mardi 15 Décembre 2015</strong></p>
    <ul>
        <li>
            <p>Les big data configurent un processus social qui a été décrit par Thomas Berns et Antoinette Rouvroy comme l’avènement d’une gouvernementalité algorithmique. Outre la crise de la science statistique et de l’épistémè contemporaine (c’est à dire de l’articulation entre les savoir-faire, les savoir vivre et les savoirs académiques) que provoque le corrélationnisme des mathématiques algorithmiquement appliquées, la gouvernementalité algorithmique s’achemine vers l’époque du deep learning.
            <br>Comment concevoir des agencements entre artifices computationnels et actions rationnelles des individus psychiques et collectifs qui ne conduisent pas à la standardisation massive des comportements et des représentations – c’est à dire à l’effondrement des capacités néguentropiques caractéristiques de l’homme ?</p>
            <p><strong>Intervenants</strong> : Olivier Grise (Inria), David Berry (Université de Sussex), Thomas Berns (Université libre de Bruxelles), Paul Jorion (Anthropologue)</p>
        </li>
    </ul>
    ",

   	'link' => 'http://enmi-conf.org/wp/enmi15/session-3/',

   	'islive'     => true,

   	'keywords'   => 'iri, nouveau monde industriel, savoir, numérique',

   	'rep' => basename(__DIR__),

    'partenaires'=> "Organisateurs: <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>IRI</a>
    | <a href='http://www.capdigital.com/' class='footerLink' target='_blank'>Cap Digital</a>
     - Partenaires Scientifiques: <a href='http://www.mines-telecom.fr/fr_accueil.html' class='footerLink' target='_blank'>Institut Mines-Télécom</a>
    | <a href='http://www.francetelevisions.fr/' class='footerLink' target='_blank'>France Télévisions</a>
    | <a href='http://www.stratecollege.fr/' class='footerLink' target='_blank'>Strate</a>",

    'client_visual' => 'images/client_visual.jpg',// 480 × 320 pixels

 	'head_logo' => 'images/logo-enmi.png', // 171 × 63 pixels

  	'slide_background' => 'images/slide_background.jpg', // 606 × 282 pixels

  	'archive_img' => 'images/archive_img.jpg', // 270 × 150 pixels

 	'archive_title' => "ENMI 2015 - Session 3 : Espace public, études digitales et éditorialisation",
 	'archive_description' => 'Olivier Grise (Inria), David Berry (Université de Sussex), Thomas Berns (Université libre de Bruxelles), Paul Jorion (Anthropologue)',

    // After the event
	'metadata'    => "093c26a0-a346-11e5-8011-00145ea4a2be"
);

==> V06.006.zip: tweet_live-V06.006/web/enmi15/session-3/config.php <==
<?php
$config = array(
   	'hashtag'    => '#enmi15',
    'annotation_protocol_version' => '2',

   	'title' => "Entretiens du Nouveau Monde Industriel 2015, Session 3",

	'abstract'   => "<b>LA TOILE QUE NOUS VOULONS</b><br>Du web sémantique au web herméneutique<br>
    <p>Paris. Centre Pompidou. Grande Salle.<br>
    14 et 15 décembre 2015<br>
    <a href=\"http://enmi-conf.org\" target=\"_blank\">http://enmi-conf.org</a>
    </p>",

   	'description'=> "<h3>Espace public, études digitales et éditorialisation</h3>
    <p><strong>Mardi 15 Décembre 2015</strong></p>
    <ul>
        <li>
            <p>Les big data configurent un processus social qui a été décrit par Thomas Berns et Antoinette Rouvroy comme l’avènement d’une gouvernementalité algorithmique. Outre la crise de la science statistique et de l’épistémè contemporaine (c’est à dire de l’articulation entre les savoir-faire, les savoir vivre et les savoirs académiques) que provoque le corrélationnisme des mathématiques algorithmiquement appliquées, la gouvernementalité algorithmique s’achemine vers l’époque du deep learning.
            <br>Comment concevoir des agencements entre artifices computationnels et actions rationnelles des individus psychiques et collectifs qui ne conduisent pas à la standardisation massive des comportements et des représentations – c’est à dire à l’effondrement des capacités néguentropiques caractéristiques de l’homme ?</p>
            <p><strong>Intervenants</strong> : Olivier Grise (Inria), David Berry (Université de Sussex), Thomas Berns (Université libre de Bruxelles), Paul Jorion (Anthropologue)</p>
        </li>
    </ul>
    ",

   	'link' => 'http://enmi-conf.org/wp/enmi15/session-3/',

   	'islive'     => true,

   	'keywords'   => 'iri, nouveau monde industriel, savoir, numérique',

   	'rep' => basename(__DIR__),

    'partenaires'=> "Organisateurs: <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>IRI</a>
    | <a href='http://www.capdigital.com/' class='footerLink' target='_blank'>Cap Digital</a>
     - Partenaires Scientifiques: <a href='http://www.mines-telecom.fr/fr_accueil.html' class='footerLink' target='_blank'>Institut Mines-Télécom</a>
    | <a href='http://www.francetelevisions.fr/' class='footerLink' target='_blank'>France Télévisions</a>
    | <a href='https://www.strate.design' class='footerLink' target='_blank' title='strate école de design' rel='nofollow noopener'>Strate</a>",

    'client_visual' => 'images/client_visual.jpg',// 480 × 320 pixels

 	'head_logo' => 'images/logo-enmi.png', // 171 × 63 pixels

  	'slide_background' => 'images/slide_background.jpg', // 606 × 282 pixels

  	'archive_img' => 'images/archive_img.jpg', // 270 × 150 pixels

 	'archive_title' => "ENMI 2015 - Session 3 : Espace public, études digitales et éditorialisation",
 	'archive_description' => 'Olivier Grise (Inria), David Berry (Université de Sussex), Thomas Berns (Université libre de Bruxelles), Paul Jorion (Anthropologue)',

    // After the event
	'metadata'    => "093c26a0-a346-11e5-8011-00145ea4a2be"
);
